==> ka-table-4.3.0.tgz: package/Components/PagingPages/PagingPages.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import * as React from 'react';
import defaultOptions from '../../defaultOptions';
import { getElementCustomization } from '../../Utils/ComponentUtils';
import { centerLength, getPagesForCenter } from '../../Utils/PagingUtils';
import PagingIndex from '../PagingIndex/PagingIndex';
var PagingPages = function (props) {
    var childComponents = props.childComponents, _a = props.pageIndex, pageIndex = _a === void 0 ? 1 : _a, pages = props.pages;
    var isEndShown = pageIndex < pages.length - centerLength && pages.length > centerLength + Math.ceil(centerLength / 2);
    var isStartShown = pageIndex >= centerLength && pages.length > centerLength + Math.ceil(centerLength / 2);
    var centerPages = getPagesForCenter(pages, isStartShown, isEndShown, pageIndex);
    var _b = getElementCustomization({
        className: defaultOptions.css.pagingPages
    }, props, childComponents.pagingPages), elementAttributes = _b.elementAttributes, content = _b.content;
    return (React.createElement("div", __assign({}, elementAttributes), content || (React.createElement(React.Fragment, null,
        isStartShown &&
            (React.createElement(React.Fragment, null,
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: 0, isActive: pageIndex === 0, text: 1 })),
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: centerPages[0] - 1, isActive: false, text: '...' })))),
        centerPages.map(function (value, index) {
            return (React.createElement(PagingIndex, __assign({}, props, { pageIndex: value, isActive: pageIndex === value, key: value, text: value + 1 })));
        }),
        isEndShown &&
            (React.createElement(React.Fragment, null,
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: __spreadArrays(centerPages).pop() + 1, isActive: false, text: '...' })),
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: pages[pages.length - 1], isActive: pageIndex === pages[pages.length - 1], text: pages[pages.length - 1] + 1 }))))))));
};
export default PagingPages;

==> ka-table-4.3.1.tgz: package/Components/PagingPages/PagingPages.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import * as React from 'react';
import { updatePageIndex } from '../../actionCreators';
import defaultOptions from '../../defaultOptions';
import { getElementCustomization } from '../../Utils/ComponentUtils';
import { centerLength, getPagesForCenter } from '../../Utils/PagingUtils';
import PagingIndex from '../PagingIndex/PagingIndex';
var PagingPages = function (props) {
    var childComponents = props.childComponents, pages = props.pages, dispatch = props.dispatch;
    var _a = props.pageIndex, pageIndex = _a === void 0 ? 0 : _a;
    if (pageIndex !== 0 && pageIndex >= pages.length) {
        dispatch(updatePageIndex(0));
    }
    var isEndShown = pageIndex < pages.length - centerLength && pages.length > centerLength + Math.ceil(centerLength / 2);
    var isStartShown = pageIndex >= centerLength && pages.length > centerLength + Math.ceil(centerLength / 2);
    var centerPages = getPagesForCenter(pages, isStartShown, isEndShown, pageIndex);
    var _b = getElementCustomization({
        className: defaultOptions.css.pagingPages
    }, props, childComponents.pagingPages), elementAttributes = _b.elementAttributes, content = _b.content;
    return (React.createElement("div", __assign({}, elementAttributes), content || (React.createElement(React.Fragment, null,
        isStartShown &&
            (React.createElement(React.Fragment, null,
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: 0, isActive: pageIndex === 0, text: 1 })),
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: centerPages[0] - 1, isActive: false, text: '...' })))),
        centerPages.map(function (value, index) {
            return (React.createElement(PagingIndex, __assign({}, props, { pageIndex: value, isActive: pageIndex === value, key: value, text: value + 1 })));
        }),
        isEndShown &&
            (React.createElement(React.Fragment, null,
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: __spreadArrays(centerPages).pop() + 1, isActive: false, text: '...' })),
                React.createElement(PagingIndex, __assign({}, props, { pageIndex: pages[pages.length - 1], isActive: pageIndex === pages[pages.length - 1], text: pages[pages.length - 1] + 1 }))))))));
};
export default PagingPages;
